==> teamapps-application-server-0.4-sources.jar: org/teamapps/model/controlcenter/UdbChatChannel.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.*;
import org.teamapps.universaldb.index.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.pojo.template.*;
import org.teamapps.universaldb.transaction.*;
import org.teamapps.universaldb.record.*;

import java.util.*;
import java.time.*;
import java.io.*;
import java.util.concurrent.*;
import java.util.function.Supplier;


public class UdbChatChannel extends AbstractUdbEntity<ChatChannel> implements ChatChannel {
	protected static TableIndex table;
	protected static IntegerIndex metaCreationDate;
	protected static IntegerIndex metaCreatedBy;
	protected static IntegerIndex metaModificationDate;
	protected static IntegerIndex metaModifiedBy;
	protected static IntegerIndex metaDeletionDate;
	protected static IntegerIndex metaDeletedBy;
	protected static TextIndex title;
	protected static MultiReferenceIndex chatMessages;

    private static void setTableIndex(TableIndex tableIndex) {
        table = tableIndex;
		metaCreationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATION_DATE);
		metaCreatedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATED_BY);
		metaModificationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFICATION_DATE);
		metaModifiedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFIED_BY);
		metaDeletionDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETION_DATE);
		metaDeletedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETED_BY);
		title = (TextIndex) tableIndex.getColumnIndex(FIELD_TITLE);
		chatMessages = (MultiReferenceIndex) tableIndex.getColumnIndex(FIELD_CHAT_MESSAGES);
    }

    public static List<ChatChannel> getAll() {
        return new EntityBitSetList<>(ChatChannel.getBuilder(), table.getRecordBitSet());
    }

    public static List<ChatChannel> sort(List<ChatChannel> list, String sortFieldName, boolean ascending, String ... path) {
    	return sort(table, list, sortFieldName, ascending, path);
    }

    public static List<ChatChannel> sort(BitSet recordIds, String sortFieldName, boolean ascending, String ... path) {
        return sort(table, ChatChannel.getBuilder(), recordIds, sortFieldName, ascending, path);
    }

    public static int getCount() {
        return table.getCount();
    }

    public UdbChatChannel() {
        super(table);
    }

    public UdbChatChannel(int id, boolean createEntity) {
        super(table, id, createEntity);
    }

    @Override
    public ChatChannel build() {
        return new UdbChatChannel();
    }

    @Override
    public ChatChannel build(int id) {
        return new UdbChatChannel(id, false);
    }

	@Override
	public Instant getMetaCreationDate() {
	    return getTimestampValue(metaCreationDate);
	}

	@Override
	public ChatChannel setMetaCreationDate(Instant value) {
	    setTimestampValue(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaCreationDate);
	}

	@Override
	public ChatChannel setMetaCreationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaCreationDate);
		return this;
	}

	@Override
	public long getMetaCreationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaCreationDate);
	}

	@Override
	public ChatChannel setMetaCreationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreatedBy() {
        return getIntValue(metaCreatedBy);
	}

	@Override
	public ChatChannel setMetaCreatedBy(int value) {
	    setIntValue(value, this.metaCreatedBy);
		return this;
	}

	@Override
	public Instant getMetaModificationDate() {
	    return getTimestampValue(metaModificationDate);
	}

	@Override
	public ChatChannel setMetaModificationDate(Instant value) {
	    setTimestampValue(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModificationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaModificationDate);
	}

	@Override
	public ChatChannel setMetaModificationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaModificationDate);
		return this;
	}

	@Override
	public long getMetaModificationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaModificationDate);
	}

	@Override
	public ChatChannel setMetaModificationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModifiedBy() {
        return getIntValue(metaModifiedBy);
	}

	@Override
	public ChatChannel setMetaModifiedBy(int value) {
	    setIntValue(value, this.metaModifiedBy);
		return this;
	}

	@Override
	public Instant getMetaDeletionDate() {
	    return getTimestampValue(metaDeletionDate);
	}

	@Override
	public ChatChannel setMetaDeletionDate(Instant value) {
	    setTimestampValue(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletionDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaDeletionDate);
	}

	@Override
	public ChatChannel setMetaDeletionDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public long getMetaDeletionDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaDeletionDate);
	}

	@Override
	public ChatChannel setMetaDeletionDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletedBy() {
        return getIntValue(metaDeletedBy);
	}

	@Override
	public ChatChannel setMetaDeletedBy(int value) {
	    setIntValue(value, this.metaDeletedBy);
		return this;
	}

	@Override
	public String getTitle() {
        return getTextValue(title);
	}

	@Override
	public ChatChannel setTitle(String value) {
	    setTextValue(value, this.title);
		return this;
	}

	@Override
	public List<ChatMessage> getChatMessages() {
	    return getMultiReferenceValue(chatMessages, ChatMessage.getBuilder());
	}

	@Override
	public ChatChannel setChatMessages(List<ChatMessage> value) {
		setMultiReferenceValue(value, chatMessages);
		return this;
	}

	@Override
	public int getChatMessagesCount() {
	    return getMultiReferenceValueCount(chatMessages, ChatMessage.getBuilder());
	}

	@Override
	public ChatChannel setChatMessages(ChatMessage ... value) {
		setMultiReferenceValue(Arrays.asList(value), chatMessages);
		return this;
	}

	@Override
	public BitSet getChatMessagesAsBitSet() {
	    return getMultiReferenceValueAsBitSet(chatMessages, ChatMessage.getBuilder());
	}

	@Override
	public ChatChannel addChatMessages(List<ChatMessage> value) {
		addMultiReferenceValue(value, chatMessages);
		return this;
	}

	@Override
	public ChatChannel addChatMessages(ChatMessage ... value) {
		addMultiReferenceValue(Arrays.asList(value), chatMessages);
		return this;
	}

	@Override
	public ChatChannel removeChatMessages(List<ChatMessage> value) {
		removeMultiReferenceValue(value, chatMessages);
		return this;
	}

	@Override
	public ChatChannel removeChatMessages(ChatMessage ... value) {
		removeMultiReferenceValue(Arrays.asList(value), chatMessages);
		return this;
	}

	@Override
	public ChatChannel removeAllChatMessages() {
		removeAllMultiReferenceValue(chatMessages);
		return this;
	}


    @Override
    public UdbChatChannel save(Transaction transaction, boolean strictChangeVerification) {
        save(transaction, table, strictChangeVerification);
        return this;
    }

    @Override
    public UdbChatChannel saveTransactional(boolean strictChangeVerification) {
        save(UniversalDB.getThreadLocalTransaction(), table, strictChangeVerification);
        return this;
    }

    @Override
    public UdbChatChannel save() {
        save(table);
        return this;
    }

    @Override
    public void delete(Transaction transaction) {
        delete(transaction, table);
    }

    @Override
    public void delete() {
        delete(table);
    }
}

==> teamapps-application-server-0.7-sources.jar: org/teamapps/model/controlcenter/UdbChatChannel.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.*;
import org.teamapps.universaldb.index.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.pojo.template.*;
import org.teamapps.universaldb.transaction.*;
import org.teamapps.universaldb.record.*;

import java.util.*;
import java.time.*;
import java.io.*;
import java.util.concurrent.*;
import java.util.function.Supplier;


public class UdbChatChannel extends AbstractUdbEntity<ChatChannel> implements ChatChannel {
	protected static TableIndex table;
	protected static IntegerIndex metaCreationDate;
	protected static IntegerIndex metaCreatedBy;
	protected static IntegerIndex metaModificationDate;
	protected static IntegerIndex metaModifiedBy;
	protected static IntegerIndex metaDeletionDate;
	protected static IntegerIndex metaDeletedBy;
	protected static IntegerIndex metaRestoreDate;
	protected static IntegerIndex metaRestoredBy;
	protected static TextIndex title;
	protected static MultiReferenceIndex chatMessages;

    private static void setTableIndex(TableIndex tableIndex) {
        table = tableIndex;
		metaCreationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATION_DATE);
		metaCreatedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATED_BY);
		metaModificationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFICATION_DATE);
		metaModifiedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFIED_BY);
		metaDeletionDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETION_DATE);
		metaDeletedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETED_BY);
		metaRestoreDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_RESTORE_DATE);
		metaRestoredBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_RESTORED_BY);
		title = (TextIndex) tableIndex.getColumnIndex(FIELD_TITLE);
		chatMessages = (MultiReferenceIndex) tableIndex.getColumnIndex(FIELD_CHAT_MESSAGES);
    }

    public static List<ChatChannel> getAll() {
        return new EntityBitSetList<>(ChatChannel.getBuilder(), table.getRecordBitSet());
    }

    public static List<ChatChannel> getDeletedRecords() {
        return new EntityBitSetList<>(ChatChannel.getBuilder(), table.getDeletedRecordsBitSet());
    }

    public static List<ChatChannel> sort(List<ChatChannel> list, String sortFieldName, boolean ascending, String ... path) {
    	return sort(table, list, sortFieldName, ascending, path);
    }

    public static List<ChatChannel> sort(BitSet recordIds, String sortFieldName, boolean ascending, String ... path) {
        return sort(table, ChatChannel.getBuilder(), recordIds, sortFieldName, ascending, path);
    }

    public static int getCount() {
        return table.getCount();
    }

    public UdbChatChannel() {
        super(table);
    }

    public UdbChatChannel(int id, boolean createEntity) {
        super(table, id, createEntity);
    }

    @Override
    public ChatChannel build() {
        return new UdbChatChannel();
    }

    @Override
    public ChatChannel build(int id) {
        return new UdbChatChannel(id, false);
    }

	@Override
	public Instant getMetaCreationDate() {
	    return getTimestampValue(metaCreationDate);
	}

	@Override
	public ChatChannel setMetaCreationDate(Instant value) {
	    setTimestampValue(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaCreationDate);
	}

	@Override
	public ChatChannel setMetaCreationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaCreationDate);
		return this;
	}

	@Override
	public long getMetaCreationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaCreationDate);
	}

	@Override
	public ChatChannel setMetaCreationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreatedBy() {
        return getIntValue(metaCreatedBy);
	}

	@Override
	public ChatChannel setMetaCreatedBy(int value) {
	    setIntValue(value, this.metaCreatedBy);
		return this;
	}

	@Override
	public Instant getMetaModificationDate() {
	    return getTimestampValue(metaModificationDate);
	}

	@Override
	public ChatChannel setMetaModificationDate(Instant value) {
	    setTimestampValue(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModificationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaModificationDate);
	}

	@Override
	public ChatChannel setMetaModificationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaModificationDate);
		return this;
	}

	@Override
	public long getMetaModificationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaModificationDate);
	}

	@Override
	public ChatChannel setMetaModificationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModifiedBy() {
        return getIntValue(metaModifiedBy);
	}

	@Override
	public ChatChannel setMetaModifiedBy(int value) {
	    setIntValue(value, this.metaModifiedBy);
		return this;
	}

	@Override
	public Instant getMetaDeletionDate() {
	    return getTimestampValue(metaDeletionDate);
	}

	@Override
	public ChatChannel setMetaDeletionDate(Instant value) {
	    setTimestampValue(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletionDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaDeletionDate);
	}

	@Override
	public ChatChannel setMetaDeletionDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public long getMetaDeletionDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaDeletionDate);
	}

	@Override
	public ChatChannel setMetaDeletionDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletedBy() {
        return getIntValue(metaDeletedBy);
	}

	@Override
	public ChatChannel setMetaDeletedBy(int value) {
	    setIntValue(value, this.metaDeletedBy);
		return this;
	}

	@Override
	public Instant getMetaRestoreDate() {
	    return getTimestampValue(metaRestoreDate);
	}

	@Override
	public ChatChannel setMetaRestoreDate(Instant value) {
	    setTimestampValue(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoreDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaRestoreDate);
	}

	@Override
	public ChatChannel setMetaRestoreDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public long getMetaRestoreDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaRestoreDate);
	}

	@Override
	public ChatChannel setMetaRestoreDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoredBy() {
        return getIntValue(metaRestoredBy);
	}

	@Override
	public ChatChannel setMetaRestoredBy(int value) {
	    setIntValue(value, this.metaRestoredBy);
		return this;
	}

	@Override
	public String getTitle() {
        return getTextValue(title);
	}

	@Override
	public ChatChannel setTitle(String value) {
	    setTextValue(value, this.title);
		return this;
	}

	@Override
	public List<ChatMessage> getChatMessages() {
	    return getMultiReferenceValue(chatMessages, ChatMessage.getBuilder());
	}

	@Override
	public ChatChannel setChatMessages(List<ChatMessage> value) {
		setMultiReferenceValue(value, chatMessages);
		return this;
	}

	@Override
	public int getChatMessagesCount() {
	    return getMultiReferenceValueCount(chatMessages, ChatMessage.getBuilder());
	}

	@Override
	public ChatChannel setChatMessages(ChatMessage ... value) {
		setMultiReferenceValue(Arrays.asList(value), chatMessages);
		return this;
	}

	@Override
	public BitSet getChatMessagesAsBitSet() {
	    return getMultiReferenceValueAsBitSet(chatMessages, ChatMessage.getBuilder());
	}

	@Override
	public ChatChannel addChatMessages(List<ChatMessage> value) {
		addMultiReferenceValue(value, chatMessages);
		return this;
	}

	@Override
	public ChatChannel addChatMessages(ChatMessage ... value) {
		addMultiReferenceValue(Arrays.asList(value), chatMessages);
		return this;
	}

	@Override
	public ChatChannel removeChatMessages(List<ChatMessage> value) {
		removeMultiReferenceValue(value, chatMessages);
		return this;
	}

	@Override
	public ChatChannel removeChatMessages(ChatMessage ... value) {
		removeMultiReferenceValue(Arrays.asList(value), chatMessages);
		return this;
	}

	@Override
	public ChatChannel removeAllChatMessages() {
		removeAllMultiReferenceValue(chatMessages);
		return this;
	}


    @Override
    public UdbChatChannel save(Transaction transaction, boolean strictChangeVerification) {
        saveRecord(transaction, strictChangeVerification);
        return this;
    }

    @Override
    public UdbChatChannel saveTransactional(boolean strictChangeVerification) {
        saveRecord(UniversalDB.getThreadLocalTransaction(), strictChangeVerification);
        return this;
    }

    @Override
    public UdbChatChannel save() {
        saveRecord();
        return this;
    }

    @Override
    public void delete(Transaction transaction) {
        deleteRecord(transaction);
    }

    @Override
    public void delete() {
        deleteRecord();
    }

    @Override
    public void restoreDeleted() {
        restoreDeletedRecord();
    }
}
